@@ -1,6 +1,6 @@
 package Geo::Coder::OpenCage;
 # ABSTRACT: Geocode coordinates and addresses with the OpenCage Geocoder
-$Geo::Coder::OpenCage::VERSION = '0.17';
+$Geo::Coder::OpenCage::VERSION = '0.18';
 use strict;
 use warnings;
 
@@ -124,7 +124,7 @@ Geo::Coder::OpenCage - Geocode coordinates and addresses with the OpenCage Geoco
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 SYNOPSIS
 
@@ -138,7 +138,7 @@ This module provides an interface to the OpenCage geocoding service.
 
 For full details of the API visit L<https://opencagedata.com/api>.
 
-It is recommended you read the L<best pracices for using the OpenCage geocoder|https://opencagedata.com/api#bestpractices> before you start.
+It is recommended you read the L<best practices for using the OpenCage geocoder|https://opencagedata.com/api#bestpractices> before you start.
 
 =head1 METHODS
 
